@@ -5,7 +5,7 @@ class hybridlogger:
 
     @staticmethod
     def ha_log(logger, hass_api, level, message):
-        if hass_api:
+        if hass_api and hasattr(hass_api, 'log'):
             hass_api.log(message, level=level)
         else:
             if level == "DEBUG":
